searchNodes=[{"doc":"Tablex implements Decision Table. Its goal is to make domain rules easy to maintain.","ref":"Tablex.html","title":"Tablex","type":"module"},{"doc":"See Tablex.Decider.decide/2 .","ref":"Tablex.html#decide/2","title":"Tablex.decide/2","type":"function"},{"doc":"See Tablex.Decider.decide/3 .","ref":"Tablex.html#decide/3","title":"Tablex.decide/3","type":"function"},{"doc":"Create a new table. Example Tablex . new ( &quot;&quot;&quot; F value || color 1 &gt;90 || red 2 80..90 || orange 3 20..79 || green 4 &lt;20 || blue &quot;&quot;&quot; )","ref":"Tablex.html#new/2","title":"Tablex.new/2","type":"function"},{"doc":"The same as new/2 . Example ~ RULES &quot;&quot;&quot; F value || color 1 &gt;90 || red 2 80..90 || orange 3 20..79 || green 4 &lt;20 || blue &quot;&quot;&quot;","ref":"Tablex.html#sigil_RULES/2","title":"Tablex.sigil_RULES/2","type":"function"},{"doc":"This module is responsible for generating Elixir code from a table.","ref":"Tablex.CodeGenerate.html","title":"Tablex.CodeGenerate","type":"module"},{"doc":"Transform a table into Elixir code. Examples iex&gt; table = &quot;&quot;&quot; ...&gt; F CreditScore EmploymentStatus Debt-to-Income-Ratio || Action ...&gt; 1 700 employed &lt;0.43 || Approved ...&gt; 2 700 unemployed - || &quot;Further Review&quot; ...&gt; 3 &lt;=700 - - || Denied ...&gt; &quot;&quot;&quot; ...&gt; ...&gt; code = generate ( table ) ...&gt; is_binary ( code ) true The code generated in the above example is: case { credit_score , employment_status , debt_to_income_ratio } do { 700 , &quot;employed&quot; , debt_to_income_ratio } when is_number ( debt_to_income_ratio ) and debt_to_income_ratio &lt; 0.43 -&gt; %{ action : &quot;Approved&quot; } { 700 , &quot;unemployed&quot; , _ } -&gt; %{ action : &quot;Further Review&quot; } { credit_score , _ , _ } when is_number ( credit_score ) and credit_score &lt;= 700 -&gt; %{ action : &quot;Denied&quot; } end","ref":"Tablex.CodeGenerate.html#generate/1","title":"Tablex.CodeGenerate.generate/1","type":"function"},{"doc":"Decision engine module responsible for applying a set of rules to input data and returning the output according to the hit policy.","ref":"Tablex.Decider.html","title":"Tablex.Decider","type":"module"},{"doc":"Run the decision process on the given table, arguments, and options. Examples iex&gt; decide ( table , args ) output","ref":"Tablex.Decider.html#decide/3","title":"Tablex.Decider.decide/3","type":"function"},{"doc":"","ref":"Tablex.Decider.html#match_expect?/2","title":"Tablex.Decider.match_expect?/2","type":"function"},{"doc":"","ref":"Tablex.Decider.html#match_rule?/2","title":"Tablex.Decider.match_rule?/2","type":"function"},{"doc":"","ref":"Tablex.Decider.html#t:options/0","title":"Tablex.Decider.options/0","type":"type"},{"doc":"Parser is responsible for parsing the table from text to a Tablex.Table struct. Hit Policies Currently the following hit policies are supported: &quot;F&quot; for :first_hit &quot;C&quot; for :collect &quot;M&quot; for :merge &quot;R&quot; for :reverse_merge","ref":"Tablex.Parser.html","title":"Tablex.Parser","type":"module"},{"doc":"Parse a string into a table struct. Returns %Tablex.Table{...} if succeeds, other wise {:error, {:invalid, reason, rest}}","ref":"Tablex.Parser.html#parse/2","title":"Tablex.Parser.parse/2","type":"function"},{"doc":"Raising version of parse/2 .","ref":"Tablex.Parser.html#parse!/2","title":"Tablex.Parser.parse!/2","type":"function"},{"doc":"Parses the given binary as table. Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the table (start position) as {line, offset_to_start_of_line} . To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line . Options :byte_offset - the byte offset for the whole binary, defaults to 0 :line - the line and the byte offset into that line, defaults to {1, byte_offset} :context - the initial context value. It will be converted to a map","ref":"Tablex.Parser.html#table/2","title":"Tablex.Parser.table/2","type":"function"},{"doc":"Struct definition for tables.","ref":"Tablex.Table.html","title":"Tablex.Table","type":"module"},{"doc":"","ref":"Tablex.Table.html#t:hit_policy/0","title":"Tablex.Table.hit_policy/0","type":"type"},{"doc":"","ref":"Tablex.Table.html#t:input/0","title":"Tablex.Table.input/0","type":"type"},{"doc":"","ref":"Tablex.Table.html#t:output/0","title":"Tablex.Table.output/0","type":"type"},{"doc":"","ref":"Tablex.Table.html#t:rule/0","title":"Tablex.Table.rule/0","type":"type"},{"doc":"","ref":"Tablex.Table.html#t:t/0","title":"Tablex.Table.t/0","type":"type"},{"doc":"","ref":"Tablex.Table.html#t:var_name/0","title":"Tablex.Table.var_name/0","type":"type"},{"doc":"","ref":"Tablex.Table.html#t:var_type/0","title":"Tablex.Table.var_type/0","type":"type"},{"doc":"","ref":"Tablex.Variable.html","title":"Tablex.Variable","type":"module"},{"doc":"","ref":"Tablex.Variable.html#t:t/0","title":"Tablex.Variable.t/0","type":"type"},{"doc":"","ref":"Tablex.Variable.html#t:var_type/0","title":"Tablex.Variable.var_type/0","type":"type"},{"doc":"Tablex is an implementation of the Decision Table in Elixir. Its goal is to make maitaining domain rules easy.","ref":"readme.html","title":"Tablex - Decision Tables in Elixir Code","type":"extras"},{"doc":"Let's assume we decide what to do everyday based on day of week and the weather, as the following table indicates: Day (string) Weather (string) Activity 1 Monday, Tuesday, Wednesday, Thursday rainy read 2 - read, walk 3 Friday sunny soccer 4 - swim 5 Saturday - watch movie, games 6 Sunday - null We can use a similar tabular form of the code in an Elixir program: ...&gt; plans = Tablex . new ( &quot;&quot;&quot; ...&gt; F Day (string) Weather (string) || Activity ...&gt; 1 Monday,Tuesday,Wednesday,Thursday rainy || read ...&gt; 2 Monday,Tuesday,Wednesday,Thursday - || read,walk ...&gt; 3 Friday sunny || soccer ...&gt; 4 Friday - || swim ...&gt; 5 Saturday - || &quot;watch movie&quot;,games ...&gt; 6 Sunday - || null ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; Tablex . decide ( plans , day : &quot;Monday&quot; ) %{ activity : [ &quot;read&quot; , &quot;walk&quot; ] } ...&gt; ...&gt; Tablex . decide ( plans , day : &quot;Friday&quot; , weather : &quot;sunny&quot; ) %{ activity : &quot;soccer&quot; } ...&gt; ...&gt; Tablex . decide ( plans , day : &quot;Sunday&quot; ) %{ activity : nil } The above code demonstrates how we can determine what to do based on a set of rules which are represented in a decision table on day and weather condition. Inside the table, we defined the decision logic with: An indicator of hit policy, F in this case meaning the first rule matched will be applied. See Hit Policies section for more information. Two input stubs, day and weather which are both strings. See Input Stubs section An output stub, activity in this case. See Output Stubs section Six rules which take inputs and determine the acitivity output. See Rules section A friendly expression in each cell of the rules. See Expression section","ref":"readme.html#quick-demo","title":"Tablex - Decision Tables in Elixir Code - Quick demo","type":"extras"},{"doc":"Inputs can be defined with a set of name (type[, description]) pairs. For example: Age (integer) defines an input field whose name is &quot;age&quot; and type is integer. DOB (date, date of birth) defines a date input field with a description label. Name Names can contain spaces in them if they are quoted. The following names are valid: year_month_day yearMonthDay &quot;year month day&quot; They will all be converted to year_month_day . Type Currently the following types are supported: integer float number string bool When types are specified, the input value shall be of the same type as specified.","ref":"readme.html#input-stubs","title":"Tablex - Decision Tables in Elixir Code - Input Stubs","type":"extras"},{"doc":"Output stubs are defined as name (type[, description]) where name can be a string which will be converted to an underscored atom; type can be either of the supported types (the same as inputs, see above section); description is optional and is currently ignored.","ref":"readme.html#output-stubs","title":"Tablex - Decision Tables in Elixir Code - Output Stubs","type":"extras"},{"doc":"After output stub definitions, each of the following rows defines a rule entry, with the format: rule_number input_exp_1 input_exp_2 ... input_exp_m || output_exp_1 output_exp_2 ... output_exp_n Rule number is primarily used for ordering. The rule with the lowest rule number has the highest priority. Input expressions and output expressions are separated by &quot;||&quot;.","ref":"readme.html#rules","title":"Tablex - Decision Tables in Elixir Code - Rules","type":"extras"},{"doc":"Currently only these types are supported: literal numeric value: integer and float (without scientific notation) literal quoted string in &quot; boolean comparation: &gt; , &gt;= , &lt; , &lt;= range, e.g. 5..10 nil (&quot;null&quot;) list of numeric, string, range, bool, nil or comparation; can be mixed any (&quot;-&quot;) The following types of expressions are planned: date time datetime function","ref":"readme.html#expression","title":"Tablex - Decision Tables in Elixir Code - Expression","type":"extras"},{"doc":"There are several hit policies to indicate how matched rules are applied. F (First matched) - the first matched rule will be applied. C (Collect) - all matched rules will be collected into result list. M (Merge) - all matched rules will be reduced (merged) into a single return entry, until there's no - in the output. R (Reverse Merge) - similar to merge but in a reversed order. Examples: First Hit iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; F Age (integer) || f (float) ...&gt; 1 &gt; 60 || 3.0 ...&gt; 2 50..60 || 2.5 ...&gt; 3 31..49 || 2.0 ...&gt; 4 15..18,20..30 || 1.0 ...&gt; 5 - || 0 ...&gt; &quot;&quot;&quot; ...&gt; ) ...&gt; ...&gt; Tablex . decide ( table , age : 30 ) %{ f : 1.0 } iex&gt; Tablex . decide ( table , age : 55 ) %{ f : 2.5 } iex&gt; Tablex . decide ( table , age : 22 ) %{ f : 1.0 } iex&gt; Tablex . decide ( table , age : 17 ) %{ f : 1.0 } iex&gt; Tablex . decide ( table , age : 1 ) %{ f : 0 } iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; F Age (integer) &quot;Years of Service&quot; || Holidays (integer) ...&gt; 1 &gt;=60 - || 3 ...&gt; 2 45..59 &lt;30 || 2 ...&gt; 3 - &gt;=30 || 22 ...&gt; 4 &lt;18 - || 5 ...&gt; 5 - - || 10 ...&gt; &quot;&quot;&quot; ...&gt; ) ...&gt; ...&gt; Tablex . decide ( table , age : 46 , years_of_service : 30 ) %{ holidays : 22 } ...&gt; iex&gt; Tablex . decide ( table , age : 17 , years_of_service : 5 ) %{ holidays : 5 } ...&gt; iex&gt; Tablex . decide ( table , age : 22 ) %{ holidays : 10 } Collect Here's an example of collect hit policy: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; C OrderAmount Membership || Discount ...&gt; 1 &gt;=100 false || &quot;Free cupcake&quot; ...&gt; 2 &gt;=100 true || &quot;Free icecream&quot; ...&gt; 3 - true || &quot;20% OFF&quot; ...&gt; &quot;&quot;&quot; ...&gt; ) ...&gt; iex&gt; Tablex . decide ( table , order_amount : 500 , membership : false ) [ %{ discount : &quot;Free cupcake&quot; } ] ...&gt; iex&gt; Tablex . decide ( table , order_amount : 500 , membership : true ) [ %{ discount : &quot;Free icecream&quot; } , %{ discount : &quot;20% OFF&quot; } ] ...&gt; iex&gt; Tablex . decide ( table , order_amount : 80 ) [ ] Collect policy can work without any input: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; C || Country FeatureVersion ...&gt; 1 || &quot;New Zealand&quot; 3 ...&gt; 2 || &quot;Japan&quot; 2 ...&gt; 3 || &quot;Brazil&quot; 2 ...&gt; &quot;&quot;&quot; ...&gt; ) ...&gt; iex&gt; Tablex . decide ( table , [ ] ) [ %{ country : &quot;New Zealand&quot; , feature_version : 3 } , %{ country : &quot;Japan&quot; , feature_version : 2 } , %{ country : &quot;Brazil&quot; , feature_version : 2 } ] Merge Here's an example of merge hit policy: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; M Continent Country Province || Feature1 Feature2 ...&gt; 1 Asia Thailand - || true true ...&gt; 2 America Canada BC,ON || - true ...&gt; 3 America Canada - || true false ...&gt; 4 America US - || false false ...&gt; 5 Europe France - || true - ...&gt; 6 Europe - - || false true ...&gt; &quot;&quot;&quot; ...&gt; ) ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;Asia&quot; , country : &quot;Thailand&quot; , province : &quot;ACR&quot; ) %{ feature1 : true , feature2 : true } ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;America&quot; , country : &quot;Canada&quot; , province : &quot;BC&quot; ) %{ feature1 : true , feature2 : true } ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;America&quot; , country : &quot;Canada&quot; , province : &quot;QC&quot; ) %{ feature1 : true , feature2 : false } ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;Europe&quot; , country : &quot;France&quot; ) %{ feature1 : true , feature2 : true } The rules are applied until all the output fields are determined. Reverse Merge The reverse_merge works the same as merge but the rule ordering is reversed: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; R Continent Country Province || Feature1 Feature2 ...&gt; 1 Europe - - || false true ...&gt; 2 Europe France - || true - ...&gt; 3 America US - || false false ...&gt; 4 America Canada - || true false ...&gt; 5 America Canada BC,ON || - true ...&gt; 6 Asia Thailand - || true true ...&gt; &quot;&quot;&quot; ...&gt; ) ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;Asia&quot; , country : &quot;Thailand&quot; , province : &quot;ACR&quot; ) %{ feature1 : true , feature2 : true } ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;America&quot; , country : &quot;Canada&quot; , province : &quot;BC&quot; ) %{ feature1 : true , feature2 : true } ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;America&quot; , country : &quot;Canada&quot; , province : &quot;QC&quot; ) ...&gt; %{ feature1 : true , feature2 : false } ...&gt; iex&gt; Tablex . decide ( table , continent : &quot;Europe&quot; , country : &quot;France&quot; ) %{ feature1 : true , feature2 : true }","ref":"readme.html#hit-policies","title":"Tablex - Decision Tables in Elixir Code - Hit policies","type":"extras"},{"doc":"It is feasible to generate Elixir code from a table with Tablex.CodeGenerate.generate/1 , as: table = &quot;&quot;&quot; F CreditScore EmploymentStatus Debt-to-Income-Ratio || Action 1 700 employed &lt;0.43 || Approved 2 700 unemployed - || &quot;Further Review&quot; 3 &lt;=700 - - || Denied &quot;&quot;&quot; Tablex.CodeGenerate . generate ( table ) The code generated in the above example is: case { credit_score , employment_status , debt_to_income_ratio } do { 700 , &quot;employed&quot; , debt_to_income_ratio } when is_number ( debt_to_income_ratio ) and debt_to_income_ratio &lt; 0.43 -&gt; %{ action : &quot;Approved&quot; } { 700 , &quot;unemployed&quot; , _ } -&gt; %{ action : &quot;Further Review&quot; } { credit_score , _ , _ } when is_number ( credit_score ) and credit_score &lt;= 700 -&gt; %{ action : &quot;Denied&quot; } end","ref":"readme.html#generating-elixir-code","title":"Tablex - Decision Tables in Elixir Code - Generating Elixir Code","type":"extras"},{"doc":"[x] nested input, e.g. country.name as an input stub name [x] nested output, e.g. constraints.max_distance as an output stub name [ ] support referring to other input entries in an input entry [x] support functions in output entries [ ] support input validation [ ] support output validation [ ] support Date data type [ ] support Time data type [ ] support DateTime data type [ ] vertical tables [ ] rule code format","ref":"readme.html#todos","title":"Tablex - Decision Tables in Elixir Code - TODOs","type":"extras"},{"doc":"The package can be installed by adding tablex to your list of dependencies in mix.exs : def deps do [ { :tablex , &quot;~&gt; 0.1.0&quot; } ] end The docs can be found at https://hexdocs.pm/tablex .","ref":"readme.html#installation","title":"Tablex - Decision Tables in Elixir Code - Installation","type":"extras"},{"doc":"Tablex is heavily inspired by Decision Model and Notation (DMN) and its FEEL expression language. Tablex is built on top of the awesome nimble_parsec library.","ref":"readme.html#credits","title":"Tablex - Decision Tables in Elixir Code - Credits","type":"extras"},{"doc":"Tablex is open sourced under MIT license .","ref":"readme.html#license","title":"Tablex - Decision Tables in Elixir Code - License","type":"extras"},{"doc":"When working with nested data structures, Tablex allows either checking against deep structs or outputting values on a deep path inside a map.","ref":"nested_fields.html","title":"Nested Fields","type":"extras"},{"doc":"Pathes can be defined with . separator. For instance, path.to.data which will match %{path: %{to: data}} when used in input stubs, or meandeeply merging %{path: %{to: data}} into the output when used in output stubs.","ref":"nested_fields.html#path","title":"Nested Fields - Path","type":"extras"},{"doc":"For example, we can decide whether to report an HTTP request based on it request method, request host and response status: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; F request.method request.host response.status || report ...&gt; 1 GET - - || F ...&gt; 2 - example.com - || F ...&gt; 3 - - &lt;400 || F ...&gt; 4 - - - || T ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; Tablex . decide ( table , request : %{ method : &quot;POST&quot; , host : &quot;myapp.com&quot; } , response : %{ status : 500 } ) %{ report : true } ...&gt; iex&gt; Tablex . decide ( table , request : %{ method : &quot;GET&quot; , host : &quot;myapp.com&quot; } ) %{ report : false } ...&gt; iex&gt; Tablex . decide ( table , request : %{ method : &quot;POST&quot; , host : &quot;example.com&quot; } ) %{ report : false }","ref":"nested_fields.html#nested-input-fields","title":"Nested Fields - Nested Input Fields","type":"extras"},{"doc":"When data is nested in output stubs, it will be put in a deep path. Example Following is an example of using nested output stubs in a table. iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; M &quot;Car Size&quot; &quot;Rental Duration&quot; &quot;Miles Driven&quot; || price.base price.extra_mileage_fee price.insurance_fee ...&gt; - (number, in days) (number, per day) || (number, $/day) (number, $/mile) (number, $/day) ...&gt; 1 compact &lt;=3 &lt;=100 || 50 0.25 15 ...&gt; 2 mid_size 4..7 101..200 || 70 0.30 - ...&gt; 3 full_size &gt;7 &gt; 200 || 90 0.35 25 ...&gt; 4 - - - || - - 20 ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; Tablex . decide ( ...&gt; table , ...&gt; car_size : &quot;mid_size&quot; , ...&gt; rental_duration : 7 , ...&gt; miles_driven : 101 ...&gt; ) %{ price : %{ base : 70 , extra_mileage_fee : 0.3 , insurance_fee : 20 } }","ref":"nested_fields.html#nested-output-fields","title":"Nested Fields - Nested Output Fields","type":"extras"},{"doc":"The second row can be an informative row, to indicate the type and/or description of the variables. This is useful when the input and output are getting too long. For each stub, either an input or output, the format is the same, as: ( type [ , description ] ) where type shall be one of the supported variable types, and description can be string, or not specified ( - ).","ref":"informative_row.html","title":"Informative Row","type":"extras"},{"doc":"iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; F Symptoms &quot;Test Results&quot; &quot;Medical History&quot; || Treatment Medication Follow-up ...&gt; (string) (string, either NORMAL or ABNORMAL) (string) || (string) (string) (integer, in weeks) ...&gt; 1 fever,cough NORMAL &quot;No Allergies&quot; || Rest OTC 2 ...&gt; 2 &quot;Chest Pain&quot; ABNORMAL ECG,&quot;Family Hx of Heart Disease&quot; || Hospital Prescription 1 ...&gt; 3 Headache NORMAL &quot;Migraine Hx&quot; || Rest Prescription 3 ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; for %{ name : name , type : type , desc : desc } &lt;- table . inputs , do : { name , type , desc } [ { :symptoms , :string , nil } , { :test_results , :string , &quot;either NORMAL or ABNORMAL&quot; } , { :medical_history , :string , nil } ] Descriptions are optional.","ref":"informative_row.html#examples","title":"Informative Row - Examples","type":"extras"},{"doc":"In case you want to skip some field(s), &quot;-&quot; can be used, as: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; F &quot;Customer Segment&quot; &quot;Purchase Frequency&quot; || &quot;Campaign Type&quot; Discount &quot;Email Frequency&quot; ...&gt; - (integer, times/year) || - - - ...&gt; 1 Loyal &gt;8 || Personalized &quot;20%&quot; Monthly ...&gt; 2 Occasional 2..8 || Seasonal &quot;10%&quot; Quarterly ...&gt; 3 Inactive &lt;2 || Re-engagement &quot;15%&quot; Biannually ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; for %{ name : name , type : type , desc : desc } &lt;- table . inputs , do : { name , type , desc } [ { :customer_segment , :undefined , nil } , { :purchase_frequency , :integer , &quot;times/year&quot; } ] ...&gt; Tablex . decide ( table , customer_segment : &quot;Inactive&quot; , purchase_frequency : 1 ) %{ campaign_type : &quot;Re-engagement&quot; , discount : &quot;15%&quot; , email_frequency : &quot;Biannually&quot; }","ref":"informative_row.html#skipping-stubs","title":"Informative Row - Skipping Stubs","type":"extras"},{"doc":"We can execute code in rules. This may be useful in the following scenarios: The output of a rule is not literal but should be calculated based on the input. One input field's value is based on another. Currently (v0.1.0), we only support execution in output fields. Security Warning Use this feature with extreme caution! Never trust inputs from users.","ref":"code_execution.html","title":"Code Execution","type":"extras"},{"doc":"Code is wrapped in a &quot;`&quot; pair, e.g. iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; F x || abs ...&gt; 1 &gt;=0 || `x` ...&gt; 2 &lt;0 || `-x` ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; Tablex . decide ( table , x : - 42 ) %{ abs : 42 }","ref":"code_execution.html#syntax","title":"Code Execution - Syntax","type":"extras"},{"doc":"The code is in raw Elixir format but not all syntax tokens are allowed to use. It follows the default restriction of formular . For example, the following code is not allowed: MyApp.foo() because it is not supported to invoke &quot;.&quot; operation.","ref":"code_execution.html#restriction","title":"Code Execution - Restriction","type":"extras"},{"doc":"We can refer to arbitary variable names as long as are provided in the binding argument of Tablex.decide/2 or Tablex/decide/3 . For example: iex&gt; table = Tablex . new ( &quot;&quot;&quot; ...&gt; M day_of_week || &quot;Go to Library&quot; Volunteer Blogging ...&gt; 1 1 || T - - ...&gt; 2 2 || F T - ...&gt; 3 - || F F `week_of_month == 4` ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; Tablex . decide ( table , day_of_week : 1 , week_of_month : 4 ) %{ go_to_library : true , volunteer : false , blogging : true } Note that week_of_month is not an input field but a bound variable on execution.","ref":"code_execution.html#variables","title":"Code Execution - Variables","type":"extras"},{"doc":"Functions are supported through formular 's custom function . Example: iex&gt; defmodule MyFib do ...&gt; @table Tablex . new ( &quot;&quot;&quot; ...&gt; F x || fib ...&gt; 1 0 || 0 ...&gt; 2 1 || 1 ...&gt; 3 &gt;=2 || `fib(x - 1) + fib(x - 2)` ...&gt; &quot;&quot;&quot; ) ...&gt; ...&gt; def fib ( x ) when is_integer ( x ) and x &gt;= 0 do ...&gt; %{ fib : y } = Tablex . decide ( @table , [ x : x ] , context : __MODULE__ ) ...&gt; y ...&gt; end ...&gt; end ...&gt; ...&gt; MyFib . fib ( 5 ) 5","ref":"code_execution.html#functions","title":"Code Execution - Functions","type":"extras"}]